@@ -1,6 +1,7 @@
 import os
 import sys
 
+
 def main():
     if len(sys.argv) != 2:
         print('This script do the setup for cmd.exe', 'Run:', '> win-basic-tools setup', 'Then refresh your cmd.exe', sep='\n')
@@ -19,16 +20,18 @@ def main():
     sources_path = f'{sys.exec_prefix}/Lib/site-packages/win_basic_tools/sources'
     home_path = os.path.expanduser('~')
 
-    with open(f'{home_path}\\.macros.doskey', 'w') as file:
-        file.write(
-            f'''ls=python {sources_path}\\ls.py $1 $2\n
-            ll=python {sources_path}\\ls.py -lac\n
-            which=python {sources_path}\\which.py $1\n
-            touch=python {sources_path}\\touch.py $*\n
-            cat=type $1\n
-            pwd=cd\n
-            mv=move $1 $2\n
-            rm=del $*\n''')
+    with open(f'{home_path}\\.macros.doskey', 'w') as f:
+        print(
+            f'ls=python {sources_path}\\ls.py $*',
+            f'll=python {sources_path}\\ls.py -lac $*',
+            f'which=python {sources_path}\\which.py $1',
+            f'touch=python {sources_path}\\touch.py $*',
+            'cat=type $1',
+            'pwd=cd',
+            'mv=move $1 $2',
+            'rm=del $*',
+            sep='\n',
+            file=f)
         
         
     os.system(f'reg add "HKCU\\Software\\Microsoft\\Command Processor" /v Autorun /d "doskey /macrofile=\\"{home_path}\\.macros.doskey\"" /f')
